@@ -5,10 +5,11 @@
 #' with proper dimensions.
 #'
 #' @param file source to read from. Must be one of:
-#'    * A string representing a local file with read access.
+#'    * A string representing a local file(s) with read access.
 #'    * A string representing a URL readable by [ncdf4::nc_open()].
 #'      (this includes DAP urls).
-#'    * A netcdf object returned by [ncdf4::nc_open()].
+#'    * A netcdf object returned by [ncdf4::nc_open()] or a list of such.
+#'      (Use [OpenNetCDF()] as sa helper function.)
 #' @param vars one of:
 #'    * `NULL`: reads all variables.
 #'    * a character vector with the name of the variables to read.
@@ -21,6 +22,23 @@
 #' @param ... in [GlanceNetCDF()], ignored. Is there for convenience so that a call to [ReadNetCDF()] can
 #' be also valid for [GlanceNetCDF()].
 #'
+#' @section Multifle datasets:
+#' `ReadNetCDF()` has rudimentary support for multifile datasets.
+#' If the `file` argument is a vector of files, then the function will be
+#' applied to each of them with the same arguments using [furrr::future_map()] and
+#' the result concatenated.`
+#'
+#' Array output is not supported in this case, since it's not clear how each
+#' result should be combined.
+#'
+#' If a file doesn't have the data included in a subset, then it won't be read
+#' (but the metadata will need to be processed).
+#' To read multiple times from the same multifle dataset, using [OpenNetCDF()]
+#' to first open all the connections might speed things up.
+#' Still, for now coordinates are read and parsed every time, so the process
+#' can be slow for dataset with a very large number of files.
+#'
+#'
 #' @section Subsetting:
 #' In the most basic form, `subset` will be a named list whose names must match
 #' the dimensions specified in the NetCDF file and each element must be a vector
@@ -153,11 +171,41 @@
 ReadNetCDF <- function(file, vars = NULL,
                        out = c("data.frame", "vector", "array"),
                        subset = NULL, key = FALSE) {
-    check_packages(c("ncdf4", "CFtime"), "ReadNetCDF")
+    if (getOption("readnetcdf_check_pkg", TRUE)) {
+        rlang::check_installed(c("ncdf4", "CFtime"), "for `ReadNetCDF()`.")
+    }
+
 
     out <- out[1]
     checks <- makeAssertCollection()
 
+    # This is not optimal. Maybe it's better to make ReatNetCDF() a generic
+    # and add methods for classes. Then rcdo can add the appropriate class.
+    if (inherits(file, "cdo_operation")) {
+        rlang::check_installed("rcdo", "to read rcdo commands.")
+        file <- rcdo::cdo_execute(file)
+    }
+
+    if (!inherits(file, "ncdf4") & length(file) > 1) {
+        if (out == "array") {
+            stopf("Multifile datasets are not supported for `out = 'array'`.")
+        }
+        # Checking if package is installed can be relatively expensive when
+        # looping though lots of files.
+        options(readnetcdf_check_pkg = FALSE)
+        on.exit(options(readnetcdf_check_pkg = TRUE))
+        rlang::check_installed("furrr", "to read multiple files.")
+        data <- furrr::future_map(file,
+            function(x) ReadNetCDF(x, vars = vars, out = out, subset = subset, key = key), .progress = TRUE)
+        if (out == "data.frame") {
+            data <- data.table::rbindlist(data)
+        } else if (out == "vector") {
+            data <- as.list(data.table::rbindlist(list(list(x = 1:10, y = 1:10), list(x = 1:10, y = 1:10))))
+        }
+
+        return(data)
+    }
+
     if (!inherits(file, "ncdf4")) {
         assertCharacter(file, len = 1, min.chars = 1, any.missing = FALSE, add = checks)
     }
@@ -237,7 +285,7 @@ ReadNetCDF <- function(file, vars = NULL,
     dimensions <- list()
     for (i in seq_along(dims)) {
         # if (dims[i] == "time" && ncfile$dim[[dims[i]]]$units != "") {
-        dimensions[[dims[i]]] <- .parse_time(ncfile$dim[[dims[i]]]$vals,
+        dimensions[[dims[i]]] <- try_parse_time(ncfile$dim[[dims[i]]]$vals,
                                              ncfile$dim[[dims[i]]]$units,
                                              ncfile$dim[[dims[i]]]$calendar)
         # } else {
@@ -322,8 +370,19 @@ ReadNetCDF <- function(file, vars = NULL,
                     sub[2] <- max(d)
                 }
 
-                start1 <- which(d %~% sub[1])
-                end <- which(d %~% sub[length(sub)])
+                sub <- range(sub)
+
+                d_temp <- d
+                d_temp[d_temp < sub[1]] <- NA
+                start1 <- which.min(abs(d_temp - sub[1]))
+
+                d_temp <- d
+                d_temp[d_temp > sub[2]] <- NA
+                end <- which.min(abs(d_temp - sub[2]))
+
+                if (length(start1) == 0 || length(end) == 0) {
+                    return(NULL)
+                }
 
                 start[[s]] <- min(start1, end)
                 count[[s]] <- abs(end - start1) + 1
@@ -398,9 +457,18 @@ time_units_factor <- c("days" = 24*3600,
 #' @export
 #' @rdname ReadNetCDF
 ParseNetCDFtime <- function(time) {
-    .parse_time(time$vals, time$units, time$calendar)
+    try_parse_time(time$vals, time$units, time$calendar)
 }
 
+#' @param files vector of files to open.
+#' @export
+#' @rdname ReadNetCDF
+OpenNetCDF <- function(files) {
+    rlang::check_installed(c("ncdf4", "CFtime", "furrr"), "for `OpenNetCDF()`.")
+    furrr::future_map(files, function(x) ncdf4::nc_open(x))
+}
+
+
 .parse_time <- function(time, units, calendar = NULL) {
     calendar <- tolower(calendar)
     has_since <- grepl("since", units)
@@ -412,16 +480,10 @@ ParseNetCDFtime <- function(time) {
     origin <- trimws(strsplit(units, "since")[[1]][2])
     time_unit <- trimws(strsplit(units, "since")[[1]])[1]
 
-    if (!(time_unit %in% names(time_units_factor))) {
-        warning(sprintf(gettext("time unit has unrecognised units: %s. Not parsing", domain = "R-metR"), time_unit))
-        return(time)
-    }
-
-
     if (length(calendar) != 0) {
         # browser()
         time <- as.POSIXct(CFtime::as_timestamp(CFtime::CFtime(units, calendar = calendar, offsets = time)),
-                   cal = "standard", tz = "UTC", origin = origin)
+                           cal = "standard", tz = "UTC", origin = origin)
     } else {
         time <- as.POSIXct(origin, tz = "UTC") + time*time_units_factor[time_unit]
     }
@@ -429,6 +491,16 @@ ParseNetCDFtime <- function(time) {
     return(time)
 }
 
+try_parse_time <- function(time, units, calendar) {
+    tryCatch(
+        .parse_time(time, units, calendar),
+        error = function(e) {
+            warningf("Error parsing time: %s. Returning original time.", e$message)
+            return(time)
+        }
+    )
+}
+
 .read_vars <- function(varid, ncfile, start, count) {
 
     var <- ncdf4::ncvar_get(nc = ncfile, varid = varid, collapse_degen = FALSE, start = start,
@@ -508,7 +580,7 @@ print.nc_glance <- function(x, ...) {
 
     cat("\n\n")
     cat(gettext("----- Dimensions ----- \n", domain = "R-metR"))
-    out <- lapply(x$dim, print)
+    out <- lapply(x$dims, print)
 }
 
 #' @export
@@ -537,7 +609,7 @@ print.ncvar4 <- function(x, ...) {
 print.ncdim4 <- function(x, ...) {
     # cat("$", dim$name, "\n", sep = "")
     units <- x$units
-    vals <- suppressMessages(suppressWarnings(.parse_time(x$vals, x$units, x$calendar)))
+    vals <- suppressMessages(suppressWarnings(try_parse_time(x$vals, x$units, x$calendar)))
 
     if (.is.somedate(vals)) {
         units <- ""
