@@ -49,7 +49,7 @@ StatContourFill <- ggplot2::ggproto("StatContourFill", ggplot2::Stat,
     dropped_aes = "z",
     setup_params = function(data, params) {
         if (is.null(params$global) || isTRUE(params$global.breaks)) {
-            params$breaks <- setup_breaks(data,
+            params$breaks <- setup_breaks(na.omit(data),
                                           breaks = params$breaks,
                                           bins = params$bins,
                                           binwidth = params$binwidth)
@@ -63,6 +63,13 @@ StatContourFill <- ggplot2::ggproto("StatContourFill", ggplot2::Stat,
             ggplot2:::snake_class(self)
             )
 
+        if (is.null(params$global) || isTRUE(params$global.breaks)) {
+            params$breaks <- setup_breaks(data,
+                                          breaks = params$breaks,
+                                          bins = params$bins,
+                                          binwidth = params$binwidth)
+        }
+
         # Trim off extra parameters
         params <- params[intersect(names(params), self$parameters())]
 
@@ -111,7 +118,7 @@ StatContourFill <- ggplot2::ggproto("StatContourFill", ggplot2::Stat,
         }
 
         if (!isFALSE(kriging)) {
-            check_packages("kriging", "kriging")
+            rlang::check_installed("kriging", "for kriging.")
 
             if (isTRUE(kriging)) {
                 kriging <- 40
